@@ -135,17 +135,17 @@ sub request_body_override
     }
 }
 
+=head1 AUTHORS
 
-=head1 COPYRIGHT
+Bizowie <http://bizowie.com>
 
-Copyright 2011, 2012 Ohio-Pennsylvania Software, LLC.
+=head1 COPYRIGHT AND LICENSE
 
-=head1 LICENSE
+Copyright (C) 2013 Bizowie
 
 This library is free software. You can redistribute it and/or modify it under the same terms as Perl itself.
 
 =cut
 
-
 1;
 
